/*
 * Copyright (c) 2016 Intel Corporation
 * Copyright (c) 2020 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: Apache-2.0
 */

/**
 * @file Sample app to demonstrate PWM.
 */

#include <zephyr/kernel.h>
#include <zephyr/sys/printk.h>
#include <zephyr/device.h>
#include <zephyr/drivers/pwm.h>
#include <zephyr/devicetree.h>


// PWM configuration for the two pins
#define PWM_NODE DT_PATH(soc, pwm_4001c000)
#define PWM_CHANNEL0 0              // PWM_OUT0 (Pin 22)
#define PWM_CHANNEL1 1              // PWM_OUT1 (Pin 23)
#define PWM_PERIOD_USEC 20000       // 20ms period (50Hz frequency)

void main(void)
{
    const struct device *pwm_dev = DEVICE_DT_GET(PWM_NODE);

    if (!device_is_ready(pwm_dev)) {
        printk("Error: PWM device is not ready\n");
        return;
    }

    printk("PWM device ready\n");

    uint32_t pulse_width = PWM_PERIOD_USEC / 2; // 50% duty cycle

    // Configure PWM_OUT0 (normal polarity)
    if (pwm_set(pwm_dev, PWM_CHANNEL0, PWM_PERIOD_USEC, pulse_width, PWM_POLARITY_NORMAL)) {
        printk("Failed to configure PWM channel 0\n");
    } else {
        printk("PWM channel 0 configured: 50%% duty cycle, normal polarity\n");
    }

    // Configure PWM_OUT1 (inverted polarity)
    if (pwm_set(pwm_dev, PWM_CHANNEL1, PWM_PERIOD_USEC, pulse_width, PWM_POLARITY_INVERTED)) {
        printk("Failed to configure PWM channel 1\n");
    } else {
        printk("PWM channel 1 configured: 50%% duty cycle, inverted polarity\n");
    }

    while (1) {
        k_sleep(K_MSEC(1000)); // Keep the application running
    }
}